
from formant.sdk.cloud.v2.formant_admin_api_client.models import DatapointEventTags, CustomEventType, PortForwardingSessionRecordStreamType, DeviceOfflineEventSeverity, CommandDeliveryEventType, EventSortColumn, SystemEventMetadata, DeviceOfflineEventType, CommandDeliveryEventMetadata, TaskSummaryReport, EventFilter, Label, StatefulEventStreamType, TaskSummary, EventHistogram, DeviceOnlineEventSeverity, EventExportSheetRequest, CustomEventStreamType, CommentType, CustomEvent, DeviceOfflineEventTags, AnnotationType, EventSeekQuerySeveritiesItem, CommandDeliveryEventTags, InterventionRequestType, DeviceOnlineEventStreamType, DatapointEventStreamType, EventSeekQueryTypesItem, StatefulEventMetadata, TeleopRequestData, StatefulEventType, DeviceOfflineEventStreamType, AnnotationTags, CommentStreamType, EventQuerySeveritiesItem, InterventionRequestMetadata, DeviceOnlineEvent, EventHistogramEntry, DatapointEventSeverity, TaskSummaryType, StatefulEventTags, DeviceOfflineEventMetadata, DatapointEvent, FocusedDatapoint, TaskSummaryMetadata, CommentTags, AnnotationStreamType, CustomEventTags, EventListResponse, StatefulEventSeverity, TeleopSessionRecord, PortForwardingSessionRecord, EventTriggerCommand, SystemEventStreamType, PhysicalRequestData, TaskSummaryTags, LabeledPolygon, TeleopSessionRecordStreamType, InterventionRequestStreamType, EventSeekQueryEventTypesItem, EventQueryEventTypesItem, PortForwardingSessionRecordMetadata, PortForwardingSessionRecordType, EventCounts, TeleopSessionRecordType, CustomEventMetadata, EventExportSheetResult, EventSeekQuery, SelectionRequestData, Annotation, CommandDeliveryEventStreamType, SystemEvent, TeleopSessionRecordTags, DatapointEventMetadata, CommandDeliveryEvent, TaskSummaryStreamType, EventFilterEventTypesItem, LabelingRequestData, DeviceOnlineEventTags, SystemEventTags, InterventionRequestTags, DeviceOfflineEvent, SystemEventType, DeviceOnlineEventType, EventSort, DeviceOnlineEventMetadata, AnnotationMetadata, EventQueryTypesItem, EventFilterSeveritiesItem, InterventionRequestSeverity, InterventionRequestInterventionType, TeleopSessionRecordMetadata, DatapointEventType, PortForwardingSessionRecordTags, CommentMetadata, Comment, InterventionRequest, EventQuery, EventFilterTypesItem, EventSortOrder, EventSeekQueryDirection, CustomEventSeverity, StatefulEvent
from formant.sdk.cloud.v2.formant_admin_api_client.api.event import event_controller_query
from formant.sdk.cloud.v2.formant_admin_api_client.types import *



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.event_filter import EventFilter


T = TypeVar("T", bound="EventExportSheetRequest")


@attr.s(auto_attribs=True)
class EventExportSheetRequest:
    """
    Attributes:
        filter_ (EventFilter):
        app_url_origin (str):
    """

    filter_: "EventFilter"
    app_url_origin: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        filter_ = self.filter_.to_dict()

        app_url_origin = self.app_url_origin

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "filter": filter_,
                "appUrlOrigin": app_url_origin,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.event_filter import EventFilter

        d = src_dict.copy()
        filter_ = EventFilter.from_dict(d.pop("filter"))

        app_url_origin = d.pop("appUrlOrigin")

        event_export_sheet_request = cls(
            filter_=filter_,
            app_url_origin=app_url_origin,
        )

        event_export_sheet_request.additional_properties = d
        return event_export_sheet_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.formant_admin_api_client.models import AnnotationStreamType, AnnotationType, ScopeFilterTypesItem, TagParameters, UserParametersRolesItem, SheetParameters, AnnotationField, AnnotationFieldValueTags, AnnotationFieldValuesRequest, AnnotationTemplateTags, AnnotationTags, AnnotationMetadata, UserParameters, AnnotationTemplate, AnnotationFieldType, AnnotationFieldValuesResponse, ScopeFilter, AnnotationFieldValuesRequestTags, AnnotationFieldValue, FocusedDatapoint, Annotation, AnnotationTemplateListResponse
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation import annotation_controller_post
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation_template import annotation_template_controller_list, annotation_template_controller_get_one
from formant.sdk.cloud.v2.formant_admin_api_client.types import *




from formant.sdk.cloud.v2.formant_query_api_client.models import BoundingBox, VideoMimeType, Image, QueryTypesItem, Query, Health,HealthStatus, StreamData, Location, Video, Transform, Vector3, Map, StreamAggregateData, Path, Bitset, StreamDataTags, Video,VideoMimeType, StreamAggregateDataType, QueryAggregate, PointCloud, Battery, StreamDataPointsItem, Quaternion, Goal, NumericSetEntry, StreamAggregateDataTags, ImageAnnotation, HealthStatus, Localization, StreamDataListResponse, Odometry, StreamDataType, TransformNode, Twist, Health, File
from formant.sdk.cloud.v2.formant_query_api_client.api.query import query_controller_query
from formant.sdk.cloud.v2.formant_query_api_client.types import *




from formant.sdk.cloud.v2.formant_admin_api_client.models import ImageViewConfigurationMode, PartialView, Location, Filter, PartialViewLayoutType, ViewLayoutType, ViewListResponse, Vector3, PartialViewTags, TransformTreeViewConfiguration, LocationViewport, LocationViewConfigurationBasemap, Camera, ImageViewConfiguration, PointCloudViewConfiguration, LocalizationViewConfiguration, BitsetViewConfiguration, LocationViewConfiguration, NumericViewConfiguration, ViewConfigurationType, ViewTags, View, ViewConfiguration
from formant.sdk.cloud.v2.formant_admin_api_client.api.view import view_controller_get_one, view_controller_get_all, view_controller_patch
from formant.sdk.cloud.v2.formant_admin_api_client.types import *



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="BitCondition")


@attr.s(auto_attribs=True)
class BitCondition:
    """
    Attributes:
        key (str):
        true_ (bool):
        false_ (bool):
    """

    key: str
    true_: bool
    false_: bool
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        key = self.key
        true_ = self.true_
        false_ = self.false_

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "key": key,
                "true": true_,
                "false": false_,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        key = d.pop("key")

        true_ = d.pop("true")

        false_ = d.pop("false")

        bit_condition = cls(
            key=key,
            true_=true_,
            false_=false_,
        )

        bit_condition.additional_properties = d
        return bit_condition

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="CommandProgress")


@attr.s(auto_attribs=True)
class CommandProgress:
    """
    Attributes:
        command_id (str):
        progress (int):
        pending (bool):
    """

    command_id: str
    progress: int
    pending: bool
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        command_id = self.command_id
        progress = self.progress
        pending = self.pending

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "commandId": command_id,
                "progress": progress,
                "pending": pending,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        command_id = d.pop("commandId")

        progress = d.pop("progress")

        pending = d.pop("pending")

        command_progress = cls(
            command_id=command_id,
            progress=progress,
            pending=pending,
        )

        command_progress.additional_properties = d
        return command_progress

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.formant_admin_api_client.models import DeviceListResponse, Network, OnDemandStreamPresence, DeviceDetailsSort, DeviceStreamRosLocalizationConfigurationRosVersion, PartialDevice, OsInfo, Device, TeleopJoystickConfigurationPosition, DeviceTeleopCustomStreamConfigurationRtcStreamType, OnDemandBuffer, DeviceOfflineEventSeverity, RtcInfoRtcIceServerProtocol, HwInfo, NetworkInfo, DeviceConfigurationDocument, RosTopic, DeviceProvisioning, PartialDeviceTags, CommandProgress, DeviceOfflineEventType, DeviceTeleopRosStreamConfigurationNumericControlVisualization, DeviceBlobData, OnDemandPresenceTimeRange, DeviceReportedConfigurationState, PartialDeviceType, DeviceStreamHardwareConfigurationType, DeviceTelemetryConfiguration, RtcInfoRtcIceTransportPoliciesItem, DeviceTags, VideoDevice, DeviceConfigurationTemplateTags, DeviceOnlineEventSeverity, DeviceDetailsType, DeviceStreamRosLocalizationConfigurationType, TeleopJoystickAxisConfigurationDimension, OnDemandPresenceStreamItemGroupDatapointType, NodeInfo, DeviceTeleopRosStreamConfiguration, DeviceDetailsSortOrder, DevicePortForwardingConfiguration, OnDemandPresenceStreamItemGroup, DeviceStreamRosTransformTreeConfigurationRosVersion, DeviceStreamConfiguration, DeviceDetailsListResponse, DeviceState, DeviceOfflineEventTags, ScopeFilterTypesItem, DeviceTeleopCustomStreamConfigurationMode, DeviceOnlineEventStreamType, DeviceDetails, RtcInfo, DeviceTeleopCustomStreamConfigurationNumericControlVisualization, DeviceTeleopHardwareStreamConfigurationQuality, DeviceStreamFileTailConfigurationType, DeviceStreamFileTailConfigurationFileFormat, DeviceTeleopConfiguration, DeviceTeleopRosStreamConfigurationMode, DeviceStreamRosTopicConfiguration, DeviceOfflineEventStreamType, DeviceTeleopHardwareStreamConfigurationHardwareType, DeviceStreamHardwareConfigurationQuality, DeviceTeleopRosStreamConfigurationQuality, DeviceStreamRosTopicConfigurationType, DeviceRosConfiguration, DeviceApplicationConfigurationConfigurationMap, DeviceOnlineEvent, DeviceDiskConfiguration, TeleopJoystickAxisConfiguration, DeviceDetailsTags, DeviceTeleopCustomStreamConfigurationQuality, DeviceOfflineEventMetadata, DeviceStreamCustomConfigurationType, DeviceFollower, DeviceConfiguration, DeviceDetailsSortColumn, DeviceQuery, DeviceStateEnv, DeviceTeleopHardwareStreamConfigurationMode, DeviceConfigurationDocumentTags, OnvifDevice, DeviceStreamDirectoryWatchConfigurationFileType, DeviceStreamRosLocalizationConfiguration, AdapterConfiguration, ValidationConfiguration, DeviceStreamConfigurationQuality, AudioDevice, DeviceStreamHardwareConfigurationHardwareType, DeviceStreamDirectoryWatchConfiguration, DeviceStreamTransformConfiguration, DeviceTeleopHardwareStreamConfiguration, DeviceTeleopRosStreamConfigurationRosVersion, DeviceScopeTypesItem, DeviceRealtimeConfiguration, DeviceTeleopRosStreamConfigurationAudioCodec, DeviceApplicationConfiguration, DeviceDiagnosticsConfiguration, DeviceCredentials, DeviceRosState, TeleopJoystickConfiguration, DeviceStreamRosTransformTreeConfiguration, TeleopViewConfiguration, OnDemandState, DeviceConfigurationTemplateListResponse, DeviceStreamHardwareConfiguration, DeviceOnlineEventTags, DeviceStreamCustomConfiguration, DeviceStreamConfigurationTags, DeviceStreamDirectoryWatchConfigurationType, DeviceTeleopRosStreamConfigurationTopicType, KernelInfo, DeviceConfigurationTemplate, DeviceOfflineEvent, DeviceResourcesConfiguration, DeviceScope, DeviceOnlineEventType, DeviceStreamFileTailConfiguration, OnDemandBufferBufferType, DeviceOnlineEventMetadata, DeviceTeleopCustomStreamConfiguration, DeviceType, DeviceTeleopHardwareStreamConfigurationRtcStreamType, DeviceProvisioningRequest, DeviceStreamRosTopicConfigurationRosVersion, ScopeFilter, DeviceQueryType, DeviceStreamRosTransformTreeConfigurationType
from formant.sdk.cloud.v2.formant_admin_api_client.api.device import device_controller_query, device_controller_patch, device_controller_get_one, device_controller_get_configuration, device_controller_post_configuration
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
from formant.sdk.cloud.v2.formant_admin_api_client.types import Optional




from formant.sdk.cloud.v2.formant_admin_api_client.models import Command, CommandListResponse, ScopeFilterTypesItem, CommandDeliveryEvent, CommandDeliveryEventTags, CommandRequest, Filter, FileInfo, CommandDeliveryEventType, CommandParameterMeta, CommandProgress, CommandTemplateParameterMeta, CommandTemplateTags, CommandResponse, CommandParameter, CommandDeliveryEventMetadata, CommandResponseTags, CommandTemplateListResponse, CommandTemplate, CommandResponseStreamType, CommandStreamType, CommandRequestListResponse, CommandTags, ScopeFilter, CommandQuery, CommandDeliveryEventStreamType
from formant.sdk.cloud.v2.formant_admin_api_client.api.command import command_controller_post, command_controller_query
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
